@@ -32,6 +32,11 @@ class NaiveModel(RegressorMixin):
     def get_params(self, deep=False):
         return {'look_back_len': self.look_back_len, 'targets': self.targets}
 
+    def set_params(self, **parameters):
+        self.look_back_len = parameters['look_back_len']
+        self.targets = parameters['targets']
+        return self
+
 
 class RandomModel(RegressorMixin):
     def __init__(self, min, max):
@@ -49,6 +54,10 @@ class RandomModel(RegressorMixin):
     def get_params(self, deep=False):
         return {'min': self.min, 'max': self.max}
 
+    def set_params(self, **parameters):
+        self.min = parameters['min']
+        self.max = parameters['max']
+        return self
 
 def run_benchmarking(models: list, cv, features: pd.DataFrame, targets: pd.DataFrame, metrics: list):
     """
