@@ -24,7 +24,9 @@ OPERATORS_IND = {RsiOperator.__name__: RsiOperator,
                  AdxOperator.__name__: AdxOperator,
                  BopOperator.__name__: BopOperator,
                  SmaOperator.__name__: SmaOperator,
-                 ReturnsOperator.__name__: ReturnsOperator
+                 ReturnsOperator.__name__: ReturnsOperator,
+                 MaxPriceAndReturn.__name__: MaxPriceAndReturn,
+                 MinPriceAndReturn.__name__: MinPriceAndReturn,
                  # todo: not sure
                  # CandleStickOperators.__name__: CandleStickOperators
                  }
@@ -32,8 +34,6 @@ OPERATORS_IND = {RsiOperator.__name__: RsiOperator,
 OPERATORS_RET = {ReturnsOperator.__name__: ReturnsOperator}
 
 OPERATORS_FWD = {
-                 ForwardMaxPriceAndReturn.__name__: ForwardMaxPriceAndReturn,
-                 ForwardMinPriceAndReturn.__name__: ForwardMinPriceAndReturn,
                  ForwardHighestReturn.__name__: ForwardHighestReturn,
                  # AmplitudeBasedLabelerOperator.__name__: AmplitudeBasedLabelerOperator
                  }
