@@ -4,6 +4,7 @@ from moosir_feature.transformers.managers.feature_manager import *
 from moosir_feature.transformers.tsfresh_features.feature_calculator import *
 from moosir_feature.transformers.indicators.feature_calculator import *
 from moosir_feature.transformers.basic_features.feature_calculator import *
+import moosir_feature.transformers.signal_features.feature_manager as sig_mgr
 
 
 @pytest.fixture
@@ -44,7 +45,16 @@ def _get_target_settings(setting_key: str):
         'target_col_feature_type': 'Rsi',
         'target_col_feature_subtype': RsiOperator.get_column_names()[0],
     })
-    settings = {"ts": ts, "ind": ind}
+
+    sig = SignalTargetSettings(**{
+        'win_len': 80,
+        'lookahead_len': 3,
+        'feature_name': "Peaks_All",
+        'target_col_feature_type': '',
+        'target_col_feature_subtype': 'Peaks_All',
+    })
+
+    settings = {"ts": ts, "ind": ind, "sig": sig}
     return settings[setting_key]
 
 
@@ -62,7 +72,12 @@ def _get_feature_settings(setting_key: str):
         'feature_names': ["Hour"]
     })
 
-    settings = {"ts": ts, "ind": ind, "basic": basic}
+    sig = SignalFeatureSettings(**{
+        'win_lens': [80],
+        'feature_names': ["Peaks_All"]
+    })
+
+    settings = {"ts": ts, "ind": ind, "basic": basic, "sig": sig}
     return settings[setting_key]
 
 
@@ -82,7 +97,17 @@ def _get_lag_settings(setting_key: str):
         },
         'lag_lens': [3]
     })
-    settings = {"ts": ts, "ind": ind}
+
+    sig = SignalLagSettings(**{'feature_parameters':
+        {
+            'win_lens': [80],
+            'feature_names': ["Troughs_All"]
+        },
+        'lag_lens': [3]
+    })
+
+    settings = {"ts": ts, "ind": ind, "sig": sig}
+
     return settings[setting_key]
 
 
@@ -109,6 +134,13 @@ def _assert_tsfresh_features(features, feature_settings_list):
                                 win_lens=f_settings.win_lens)
 
 
+def _assert_signal_features(features, feature_settings_list):
+    for f_settings in feature_settings_list:
+        assert sig_mgr.validate_columns(data=features,
+                                        feature_names=f_settings.feature_names,
+                                        win_lens=f_settings.win_lens)
+
+
 def _assert_tsfresh_lags(features, lag_settings_list):
     for l_settings in lag_settings_list:
         assert validate_columns(data=features,
@@ -116,6 +148,13 @@ def _assert_tsfresh_lags(features, lag_settings_list):
                                 win_lens=l_settings.win_lens)
 
 
+def _assert_signal_lags(features, lag_settings_list):
+    for l_settings in lag_settings_list:
+        assert sig_mgr.validate_columns(data=features,
+                                        feature_names=l_settings.feature_names,
+                                        win_lens=l_settings.win_lens)
+
+
 def _assert_indicator_lags(features, context, lag_settings_list):
     for l_settings in lag_settings_list:
         lag_ops = _get_indicator_operators(l_settings.feature_names)
@@ -276,3 +315,23 @@ def test_feature_manager_calculate_indicators(ohlc: pd.DataFrame):
 
     # assert lags
     _assert_indicator_lags(features=features, context=context, lag_settings_list=lag_settings_list)
+
+
+def test_feature_manager_calculate_signals(ohlc: pd.DataFrame):
+    # arrange
+    target_settings = _get_target_settings("sig")
+    feature_settings_list = [_get_feature_settings("sig")]
+    lag_settings_list = [_get_lag_settings("sig")]
+
+    # act
+    features, targets, all = _run_manager(ohlc=ohlc,
+                                          target_settings=target_settings,
+                                          feature_settings_list=feature_settings_list,
+                                          lag_settings_list=lag_settings_list)
+
+    _print(features, targets, all)
+
+    # assert
+    _assert_signal_features(features=features, feature_settings_list=feature_settings_list)
+    _assert_signal_lags(features=features, lag_settings_list=lag_settings_list)
+
